@@ -2,7 +2,7 @@
 
 # This file is part of App Launcher
 
-# Copyright © 2018-2020 Ubuntu Budgie Developers
+# Copyright © 2018 Ubuntu Budgie Developers
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,7 +14,12 @@ import gi.repository
 
 gi.require_version('Gtk', '3.0')
 gi.require_version('GMenu', '3.0')
-gi.require_version('Budgie', '1.0')
+gi.require_version('Libxfce4windowing', '0.0')
+from gi.repository import Libxfce4windowing
+if Libxfce4windowing.windowing_get() == Libxfce4windowing.Windowing.WAYLAND:
+    gi.require_version('Budgie', '2.0')
+else:
+    gi.require_version('Budgie', '1.0')
 from gi.repository import Budgie
 from gi.repository import GMenu
 from gi.repository import Gtk
@@ -102,9 +107,15 @@ class AppLauncherApplet(Budgie.Applet):
 
     def buildPopover(self):
         self.popover = Budgie.Popover.new(self.indicatorBox)
-        self.popover.set_default_size(self.popoverWidth, self.popoverHeight)
-        self.popover.get_child().show_all()
-        self.show_all()
+        if Libxfce4windowing.windowing_get() == \
+                Libxfce4windowing.Windowing.WAYLAND:
+            self.popover.set_size_request(self.popoverWidth,
+                                          self.popoverHeight)
+        else:
+            self.popover.set_default_size(self.popoverWidth,
+                                          self.popoverHeight)
+            self.popover.get_child().show_all()
+            self.show_all()
 
     def buildStack(self):
         self.stack = Gtk.Stack()
@@ -381,7 +392,7 @@ class AppLauncherApplet(Budgie.Applet):
         self.filteredActiveApps = self.filterHelper.filteredAppsByName(
             self.activeApps, self.showOnPanel, text)
 
-        if text is "":
+        if text == "":
             self.loadAppButtons()
         else:
             self.loadFilteredActiveAppButtons()
@@ -420,7 +431,7 @@ class AppLauncherApplet(Budgie.Applet):
             currentMenuButtonIndex = self.menuButtons.index(
                 self.currentMenuButton)
             activeAppsLenght = len(self.activeApps)
-            if currentMenuButtonIndex is 0:
+            if currentMenuButtonIndex == 0:
                 self.upButton.set_sensitive(False)
                 self.downButton.set_sensitive(True)
             elif currentMenuButtonIndex is activeAppsLenght - 1:
@@ -434,7 +445,7 @@ class AppLauncherApplet(Budgie.Applet):
             self.downButton.set_sensitive(False)
 
     def updateSensitiveSelectButtons(self):
-        if len(self.activeApps) is 0:
+        if len(self.activeApps) == 0:
             self.selectButton.set_sensitive(True)
             self.deselectButton.set_sensitive(False)
         elif len(self.activeApps) > 0:
